# magic_docker
Magic Docker is an automated tools to build a Docker Image


Hi there 
I hope all is well, and you are enjoying the time. 

You are using the Magic-Docker Tools. 
It is an automated python application to create an error-free Docker Image. 
The current version has been programmed for Linux and MAC Os if you are a Linux or MAC user, good news! This magical tool will take care of all the steps.
 If you are windows user, the program still will help you.
 It will create the Dockerfile, requirements, and the shell script to build and save the created docker image. "
Please feel free to contact me if you needed any further assistance. 

Thank you. 

Babak.EA






## How to install :
PyPi : 
pip install magic_docker 


## How to run : 

<b> using Jupyter notbook </b> 

import magic_docker

magic_docker.Magic()

check version : magic_docker.Magic.version()

source code : github
https://github.com/BabakEA/magic_docker


Training :

https://www.youtube.com/watch?v=Sh4PdZ9Mcn4
https://www.youtube.com/watch?v=-AQWuDLIqms
